@@ -77,9 +77,12 @@ public:
     void modelLoaded(const std::string& path, SGPropertyNode *prop, osg::Node *n)
     {
         // WARNING: Called in a separate OSG thread! Only use thread-safe stuff here...
-        if (_ready)
+        if (_ready && _modelLoaded.count(path) > 0)
             return;
 
+        _modelLoaded[path] = true;
+        _ready = true;
+
         if(prop->hasChild("interior-path")){
             _interiorPath = prop->getStringValue("interior-path");
             _hasInteriorPath = true;
@@ -88,7 +91,6 @@ public:
         _fxpath = prop->getStringValue("sound/path");
         _nasal->modelLoaded(path, prop, n);
 
-        _ready = true;
 
     }
 
@@ -109,6 +111,7 @@ private:
     std::string _fxpath;
     std::string _interiorPath;
 
+    std::map<string, bool> _modelLoaded;
     bool _ready = false;
     bool _initialized = false;
     bool _hasInteriorPath = false;
@@ -236,7 +239,8 @@ void FGAIBase::readFromScenario(SGPropertyNode* scFileNode)
     setLongitude(scFileNode->getDoubleValue("longitude", 0.0));
     setLatitude(scFileNode->getDoubleValue("latitude", 0.0));
     setBank(scFileNode->getDoubleValue("roll", 0.0));
-
+    setPitch(scFileNode->getDoubleValue("pitch", 0.0));
+    
     SGPropertyNode* submodels = scFileNode->getChild("submodels");
 
     if (submodels) {
@@ -244,6 +248,23 @@ void FGAIBase::readFromScenario(SGPropertyNode* scFileNode)
         setSMPath(submodels->getStringValue("path", ""));
     }
 
+    string searchOrder = scFileNode->getStringValue("search-order", "");
+    if (!searchOrder.empty()) {           
+        if (searchOrder == "DATA_ONLY") {
+            _searchOrder = DATA_ONLY;
+        } else if (searchOrder == "PREFER_AI") {
+            _searchOrder = PREFER_AI;
+        } else if (searchOrder == "PREFER_DATA") {
+            _searchOrder = PREFER_DATA;
+        } else
+            SG_LOG(SG_AI, SG_WARN, "invalid model search order " << searchOrder << ". Use either DATA_ONLY, PREFER_AI or PREFER_DATA");
+        
+    }
+    
+    const string modelLowres = scFileNode->getStringValue("model-lowres", "");
+    if (!modelLowres.empty()) {
+        setPathLowres(modelLowres);
+    }
 }
 
 void FGAIBase::update(double dt) {
@@ -305,16 +326,21 @@ void FGAIBase::updateInterior()
     if(!_modeldata || !_modeldata->hasInteriorPath())
         return;
 
-    if(!_modeldata->getInteriorLoaded()){ // interior is not yet load
-        double d2 = dist(SGVec3d::fromGeod(pos), globals->get_aircraft_position_cart());
-        if(d2 <= _maxRangeInterior){ // if the AI is in-range we load the interior
-            _interior = SGModelLib::loadPagedModel(_modeldata->getInteriorPath(), props, _modeldata);
-            if(_interior.valid()){
-                _interior->setRange(0, 0.0, _maxRangeInterior);
-                aip.add(_interior.get());
-                _modeldata->setInteriorLoaded(true);
-                SG_LOG(SG_AI, SG_INFO, "AIBase: Loaded interior model " << _interior->getName());
+    if (!_modeldata->getInteriorLoaded()) { // interior is not yet load
+        _interior = SGModelLib::loadPagedModel(_modeldata->getInteriorPath(), props, _modeldata);
+        if (_interior.valid()) {
+            bool pixel_mode = !fgGetBool("/sim/rendering/static-lod/aimp-range-mode-distance", false);
+            if (pixel_mode) {
+                _interior->setRangeMode(osg::LOD::PIXEL_SIZE_ON_SCREEN);
+                _interior->setRange(0, _maxRangeInterior, FLT_MAX);
             }
+            else {
+                _interior->setRangeMode(osg::LOD::DISTANCE_FROM_EYE_POINT);
+                _interior->setRange(0, 0.0, _maxRangeInterior);
+            }
+            aip.add(_interior.get());
+            _modeldata->setInteriorLoaded(true);
+            SG_LOG(SG_AI, SG_INFO, "AIBase: Loaded interior model " << _interior->getName());
         }
     }
 }
@@ -322,35 +348,46 @@ void FGAIBase::updateInterior()
 /** update LOD properties of the model */
 void FGAIBase::updateLOD()
 {
-    double maxRangeDetail = fgGetDouble("/sim/rendering/static-lod/ai-detailed", 3000.0);
-    double maxRangeBare   = fgGetDouble("/sim/rendering/static-lod/ai-bare", 10000.0);
-
-    _maxRangeInterior     = fgGetDouble("/sim/rendering/static-lod/ai-interior", 50.0);
+    double maxRangeDetail = fgGetDouble("/sim/rendering/static-lod/aimp-detailed", 3000.0);
+    double maxRangeBare   = fgGetDouble("/sim/rendering/static-lod/aimp-bare", 10000.0);
+    _maxRangeInterior     = fgGetDouble("/sim/rendering/static-lod/aimp-interior", 50.0);
 
     if (_model.valid())
     {
-        bool pixel_mode = fgGetBool("/sim/rendering/static-lod/ai-range-mode-pixel", false);
+        bool pixel_mode = !fgGetBool("/sim/rendering/static-lod/aimp-range-mode-distance", false);
+        if (pixel_mode) {
+            _model->setRangeMode(osg::LOD::PIXEL_SIZE_ON_SCREEN);
+        }
+        else {
+            _model->setRangeMode(osg::LOD::DISTANCE_FROM_EYE_POINT);
+        }
 
-        if( (int)maxRangeDetail == (int)maxRangeBare) // high detail only
+        if (maxRangeDetail < 0)
         {
-            // Disable LOD.  If we have two models set them accordingly, otherwise and largely by 
-            // definition the only model must be the model that is used.
+            // High detail model (only)
+            // - disables the low detail detail model by setting its visibility from 0 to 0
             if (_model->getNumFileNames() == 2) {
-                if (pixel_mode) {
-                    _model->setRange(modelHighDetailIndex, maxRangeDetail, FLT_MAX);
-                }
-                else {
-                    _model->setRange(modelHighDetailIndex, 0.0, maxRangeDetail);
-                }
-                _model->setRange(modelLowDetailIndex, 0.0, 0.0); // turn off
+                _model->setRange(modelHighDetailIndex, 0.0, FLT_MAX); // all ranges.
+                _model->setRange(modelLowDetailIndex, 0.0, 0.0); // turn it off
             }
             else {
-                _model->setRange(0, 0.0, FLT_MAX);
+                _model->setRange(0, 0.0, FLT_MAX); // only one model.
+            }
+        }
+        else if ((int)maxRangeBare == (int)maxRangeDetail) 
+        {
+            // low detail model  (only)
+            if (_model->getNumFileNames() == 2) {
+                _model->setRange(modelHighDetailIndex, 0, 0); // turn it off
+                _model->setRange(modelLowDetailIndex, 0, FLT_MAX);
+            }
+            else {
+                _model->setRange(0, 0, FLT_MAX);
             }
         }
         else
         {
-            if( pixel_mode)
+            if(pixel_mode)
             {
                 /* In pixel size mode, the range sense is reversed, so we want the
                 * detailed model [0] to be displayed when the "range" is really
@@ -366,20 +403,25 @@ void FGAIBase::updateLOD()
                   maxRangeBare = maxRangeDetail;
                   SG_LOG(SG_AI,
                     SG_WARN,
-                    "/sim/rendering/static-lod/ai-bare greater " <<
-                    "than /sim/rendering/static-lod/ai-detailed when using " <<
-                    "/sim/rendering/static-lod/ai-range-mode-pixel=true.  Ignoring ai-bare."
+                    "/sim/rendering/static-lod/aimp-bare greater " <<
+                    "than /sim/rendering/static-lod/aimp-detailed when using " <<
+                    "/sim/rendering/static-lod/aimp-range-mode-distance=false.  Ignoring ai-bare."
                   );
                 }
 
-                _model->setRangeMode( osg::LOD::PIXEL_SIZE_ON_SCREEN );
                 if (_model->getNumFileNames() == 2) {
+                    /*if (_model->getRadius() < 0)
+                    {
+                        osg::BoundingSphere bs = _model->computeBound();
+                        if (bs.radius() > 0) {
+                            _model->setRadius(bs.radius());
+                            _model->setCenterMode(osg::LOD::CenterMode::USER_DEFINED_CENTER);
+                        }
+                    }*/
                   _model->setRange(modelHighDetailIndex , maxRangeDetail, FLT_MAX); // most detailed
                   _model->setRange(modelLowDetailIndex , maxRangeBare, maxRangeDetail); // least detailed
                 } else {
-                  /* If we have only one LoD for this model, then we want to
-                   * display it from the smallest pixel value
-                   */
+                  // we have only one model it obviously will have to be displayed from the smallest value
                   _model->setRange(0, min(maxRangeBare, maxRangeDetail), FLT_MAX );
                 }
             } else {
@@ -387,28 +429,34 @@ void FGAIBase::updateLOD()
                  * We use the detailed model [0] for when we are up to the detailed
                  * range, and the less complex model [1] (if available) for further
                  * away up to the bare range.
+                 * - in this case the maxRangeBare is a delta on top of maxRangeDetail.
                  */
 
-                 if (maxRangeBare < maxRangeDetail) {
-                   // Sanity check that we have sensible values.
-                   maxRangeBare = maxRangeDetail;
-                   SG_LOG(SG_AI,
-                     SG_WARN,
-                     "/sim/rendering/static-lod/ai-bare less than " <<
-                     "than /sim/rendering/static-lod/ai-detailed.  Ignoring ai-bare."
-                   );
-                 }
-
-                _model->setRangeMode( osg::LOD:: DISTANCE_FROM_EYE_POINT);
-                 if (_model->getNumFileNames() == 2) {
-                  _model->setRange(modelHighDetailIndex, 0, maxRangeDetail);
-                  _model->setRange(modelLowDetailIndex, maxRangeDetail, maxRangeBare);
-                } else {
-                  /* If we have only one LoD for this model, then we want to
-                   * display it from whatever range.
-                   */
-                  _model->setRange(0, 0, max(maxRangeBare, maxRangeDetail));
+                if (maxRangeBare <= 0) {
+                    // Sanity check that we have sensible values.
+                    maxRangeBare = 1;
+                    SG_LOG(SG_AI,
+                        SG_ALERT,
+                        "/sim/rendering/static-lod/aimp-bare is <= 0. This should be a delta on top of aimp-detailed in meters mode. setting to 1.");
                 }
+
+
+                if (_model->getNumFileNames() == 2) {
+                  _model->setRange(modelHighDetailIndex , 0, maxRangeDetail); // most detailed
+                  _model->setRange(modelLowDetailIndex , maxRangeDetail, maxRangeDetail+maxRangeBare); // least detailed
+                } else {
+                  _model->setRange(0, 0, maxRangeBare + maxRangeDetail); // only one model, so display from 0 to the highest value in meters
+                }
+            }
+        }
+        if (_modeldata->getInteriorLoaded() && _interior.valid()) {
+            if (pixel_mode) {
+                _interior->setRangeMode(osg::LOD::PIXEL_SIZE_ON_SCREEN);
+                _interior->setRange(0, _maxRangeInterior, FLT_MAX);
+            }
+            else {
+                _interior->setRangeMode(osg::LOD::DISTANCE_FROM_EYE_POINT);
+                _interior->setRange(0, 0.0, _maxRangeInterior);
             }
         }
     }
@@ -452,6 +500,14 @@ std::vector<std::string> FGAIBase::resolveModelPath(ModelSearchOrder searchOrder
             _installed = true;
             SG_LOG(SG_AI, SG_DEBUG, "Found model " << p);
             path_list.push_back(p);
+            
+            if (!model_path_lowres.empty()) {
+                p = simgear::SGModelLib::findDataFile(model_path_lowres);
+                if (!p.empty()) {
+                    //lowres model needs to be the first in the list
+                    path_list.insert(path_list.begin(),p);
+                }
+            }
         } else {
             // No model, so fall back to the default
             path_list.push_back(fgGetString("/sim/multiplay/default-model", default_model));
@@ -652,7 +708,13 @@ void FGAIBase::bind() {
     props->setDoubleValue("controls/flight/target-hdg", hdg);
     props->setDoubleValue("controls/flight/target-roll", roll);
 
-    props->setStringValue("controls/flight/longitude-mode", "alt");
+    props->setStringValue("controls/flight/vertical-mode", "alt");
+
+    // The property above was incorrectly labelled 'longitude-mode' up until
+    // FG 2018.4, so create an alias in case anyone is relying on the old name
+    auto node = props->getNode("controls/flight/longitude-mode", true);
+    node->alias(props->getNode("controls/flight/vertical-mode"));
+    
     props->setDoubleValue("controls/flight/target-alt", altitude_ft);
     props->setDoubleValue("controls/flight/target-pitch", pitch);
 
