@@ -8,21 +8,21 @@
  ------------- Copyright (C) 1999  Jon S. Berndt (jon@jsbsim.org) -------------
 
  This program is free software; you can redistribute it and/or modify it under
- the terms of the GNU Lesser General Public License as published by the Free Software
- Foundation; either version 2 of the License, or (at your option) any later
- version.
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2 of the License, or (at your option) any
+ later version.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
  details.
 
- You should have received a copy of the GNU Lesser General Public License along with
- this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- Place - Suite 330, Boston, MA  02111-1307, USA.
+ You should have received a copy of the GNU Lesser General Public License along
+ with this program; if not, write to the Free Software Foundation, Inc., 59
+ Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
- Further information about the GNU Lesser General Public License can also be found on
- the world wide web at http://www.gnu.org.
+ Further information about the GNU Lesser General Public License can also be
+ found on the world wide web at http://www.gnu.org.
 
 FUNCTIONAL DESCRIPTION
 --------------------------------------------------------------------------------
@@ -41,18 +41,14 @@ COMMENTS, REFERENCES,  and NOTES
 INCLUDES
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#include <iostream>
-#include <cstdlib>
 #include <iomanip>
 
 #include "FGScript.h"
 #include "FGFDMExec.h"
-#include "input_output/FGXMLElement.h"
 #include "input_output/FGXMLFileRead.h"
 #include "initialization/FGInitialCondition.h"
 #include "models/FGInput.h"
 #include "math/FGCondition.h"
-#include "math/FGFunction.h"
 #include "math/FGFunctionValue.h"
 
 using namespace std;
@@ -142,9 +138,6 @@ bool FGScript::LoadScript(const SGPath& script, double default_dT,
     return false;
   }
 
-  // Make sure that the desired time is reached and executed.
-  EndTime += 0.99*FDMExec->GetDeltaT();
-
   if (default_dT == 0.0)
     dt = run_element->GetAttributeValueAsNumber("dt");
   else {
@@ -154,6 +147,9 @@ bool FGScript::LoadScript(const SGPath& script, double default_dT,
   }
 
   FDMExec->Setdt(dt);
+
+  // Make sure that the desired time is reached and executed.
+  EndTime += 0.99*FDMExec->GetDeltaT();
   
   // read aircraft and initialization files
 
@@ -284,8 +280,7 @@ bool FGScript::LoadScript(const SGPath& script, double default_dT,
 
         if (notify_property_element->HasAttribute("apply")) {
           string function_str = notify_property_element->GetAttributeValue("apply");
-          FGOutput* Output = FDMExec->GetOutput();
-          FGTemplateFunc* f = Output->GetTemplateFunc(function_str);
+          FGTemplateFunc* f = FDMExec->GetTemplateFunc(function_str);
           if (f)
             newEvent->NotifyProperties.push_back(new FGFunctionValue(notifyPropertyName, PropertyManager, f));
           else {
@@ -325,10 +320,10 @@ bool FGScript::LoadScript(const SGPath& script, double default_dT,
       //of value or function is specified.
       if (!set_element->GetAttributeValue("value").empty()) {
         value = set_element->GetAttributeValueAsNumber("value");
-        newEvent->Functions.push_back((FGFunction*)0L);
+        newEvent->Functions.push_back(nullptr);
       } else if (set_element->FindElement("function")) {
         value = 0.0;
-        newEvent->Functions.push_back(new FGFunction(PropertyManager, set_element->FindElement("function")));
+        newEvent->Functions.push_back(new FGFunction(FDMExec, set_element->FindElement("function")));
       }
       newEvent->SetValue.push_back(value);
       newEvent->OriginalValue.push_back(0.0);
