@@ -8,21 +8,21 @@
  ------------- Copyright (C) 2000  Jon S. Berndt (jon@jsbsim.org) --------------
 
  This program is free software; you can redistribute it and/or modify it under
- the terms of the GNU Lesser General Public License as published by the Free Software
- Foundation; either version 2 of the License, or (at your option) any later
- version.
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2 of the License, or (at your option) any
+ later version.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
  details.
 
- You should have received a copy of the GNU Lesser General Public License along with
- this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- Place - Suite 330, Boston, MA  02111-1307, USA.
+ You should have received a copy of the GNU Lesser General Public License along
+ with this program; if not, write to the Free Software Foundation, Inc., 59
+ Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
- Further information about the GNU Lesser General Public License can also be found on
- the world wide web at http://www.gnu.org.
+ Further information about the GNU Lesser General Public License can also be
+ found on the world wide web at http://www.gnu.org.
 
 FUNCTIONAL DESCRIPTION
 --------------------------------------------------------------------------------
@@ -38,13 +38,10 @@ HISTORY
 INCLUDES
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#include <iostream>
 #include <iomanip>
-#include <cstdlib>
 
 #include "FGMassBalance.h"
 #include "FGFDMExec.h"
-#include "input_output/FGPropertyManager.h"
 #include "input_output/FGXMLElement.h"
 
 using namespace std;
@@ -117,9 +114,11 @@ static FGMatrix33 ReadInertiaMatrix(Element* document)
   if (document->FindElement("iyz"))
     biyz = document->FindElementValueAsNumberConvertTo("iyz", "SLUG*FT2");
 
-  return FGMatrix33(  bixx,  -bixy,  bixz,
-                      -bixy,  biyy,  -biyz,
-                      bixz,  -biyz,  bizz );
+  // Transform the inertia products from the structural frame to the body frame
+  // and create the inertia matrix.
+  return FGMatrix33( bixx, -bixy,  bixz,
+                    -bixy,  biyy, -biyz,
+                     bixz, -biyz,  bizz );
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -165,7 +164,7 @@ bool FGMassBalance::Load(Element* document)
 
   Mass = lbtoslug*Weight;
 
-  PostLoad(document, PropertyManager);
+  PostLoad(document, FDMExec);
 
   Debug(2);
   return true;
