@@ -34,6 +34,9 @@
 #include <simgear/misc/strutils.hxx>
 #include <simgear/io/lowlevel.hxx>
 
+//#define HID_INPUT_DEBUG 1
+
+const char* hexTable = "0123456789ABCDEF";
 
 namespace HID
 {
@@ -102,12 +105,17 @@ namespace HID
         AD_CharacterReport = 0x2B,
         AD_DisplayData = 0x2C,
         AD_DisplayStatus = 0x2D,
+        AD_Rows = 0x35,
+        AD_Columns = 0x36,
+        AD_7SegmentDirectMap = 0x43,
+        AD_14SegmentDirectMap = 0x45,
         AD_DisplayBrightness = 0x46,
         AD_DisplayContrast = 0x47
     };
 
     enum class ReportType
     {
+        Invalid = 0,
         In = 0x08,
         Out = 0x09,
         Feature = 0x0B
@@ -153,7 +161,9 @@ namespace HID
                 case AD_AlphanumericDisplay:       return "alphanumeric";
                 case AD_CharacterReport:           return "character-report";
                 case AD_DisplayData:               return "display-data";
-                case AD_DisplayBrightness:         return "display-brightness";
+                case AD_DisplayBrightness:         return "display-brightness"; 
+                case AD_7SegmentDirectMap:          return "seven-segment-direct";
+                case AD_14SegmentDirectMap:         return "fourteen-segment-direct";
 
                 default:
                     SG_LOG(SG_INPUT, SG_WARN, "Unhandled HID alphanumeric usage:" << usage);
@@ -204,6 +214,13 @@ namespace HID
         return false;
     }
 
+    ReportType reportTypeFromString(const std::string& s)
+    {
+        if (s == "input") return ReportType::In;
+        if (s == "output") return ReportType::Out;
+        if (s == "feature") return ReportType::Feature;
+        return ReportType::Invalid;
+    }
 } // of namespace
 
 class FGHIDEventInput::FGHIDEventInputPrivate
@@ -227,7 +244,8 @@ public:
 
     bool Open() override;
     void Close() override;
-
+    void Configure(SGPropertyNode_ptr node) override;
+    
     void update(double dt) override;
     const char *TranslateEventName(FGEventData &eventData) override;
     void Send( const char * eventName, double value ) override;
@@ -273,8 +291,9 @@ private:
         }
     };
 
-    void scanCollection(hid_item* collection);
-    void scanItem(hid_item* item);
+    bool parseUSBHIDDescriptor();
+    void parseCollection(hid_item* collection);
+    void parseItem(hid_item* item);
 
     Report* getReport(HID::ReportType ty, uint8_t number, bool doCreate = false);
 
@@ -288,11 +307,18 @@ private:
 
     int maybeSignExtend(Item* item, int inValue);
 
+    void defineReport(SGPropertyNode_ptr reportNode);
+    
     std::vector<Report*> _reports;
     std::string _hidPath;
     hid_device* _device = nullptr;
     bool _haveNumberedReports = false;
-
+    
+    /// set if we parsed the device description our XML
+    /// instead of from the USB data. Useful on Windows where the data
+    /// is inaccessible, or devices with broken descriptors
+    bool _haveLocalDescriptor = false;
+    
     // all sets which will be send on the next update() call.
     std::set<Report*> _dirtyReports;
 };
@@ -315,30 +341,26 @@ FGHIDDevice::FGHIDDevice(hid_device_info *devInfo, FGHIDEventInput *)
 {
     _hidPath = devInfo->path;
 
-    std::wstring manufactuerName,
+    std::wstring manufacturerName,
         productName = std::wstring(devInfo->product_string);
     if (devInfo->manufacturer_string) {
-        manufactuerName = std::wstring(devInfo->manufacturer_string);
-        SetName(simgear::strutils::convertWStringToUtf8(manufactuerName) + " " +
+        manufacturerName = std::wstring(devInfo->manufacturer_string);
+        SetName(simgear::strutils::convertWStringToUtf8(manufacturerName) + " " +
             simgear::strutils::convertWStringToUtf8(productName));
     } else {
         SetName(simgear::strutils::convertWStringToUtf8(productName));
     }
 
     const auto serial = devInfo->serial_number;
-    // every device so far encountered returns a blank serial number, so we
-    // fall back to the device path to disambiguate.
     std::string path(devInfo->path);
-    if ((serial == nullptr) || std::wcslen(serial) == 0) {
-        // use device path to disambiguate
-        if (!path.empty()) {
-            SG_LOG(SG_INPUT, SG_INFO, "Missing serial on device '" <<
-            simgear::strutils::convertWStringToUtf8(productName) << "', using path: " << path);
-            SetSerialNumber(path);
-        }
-    } else {
+    // most devices return an empty serial number, unfortunately
+    if ((serial != nullptr) && std::wcslen(serial) > 0) {
         SetSerialNumber(simgear::strutils::convertWStringToUtf8(serial));
     }
+
+#if defined(HID_INPUT_DEBUG)
+    SG_LOG(SG_INPUT, SG_INFO, "HID device:" << GetName() << " at path " << _hidPath);
+#endif
 }
 
 FGHIDDevice::~FGHIDDevice()
@@ -348,6 +370,21 @@ FGHIDDevice::~FGHIDDevice()
     }
 }
 
+void FGHIDDevice::Configure(SGPropertyNode_ptr node)
+{
+    // base class first
+    FGInputDevice::Configure(node);
+    
+    if (node->hasChild("hid-descriptor")) {
+        _haveLocalDescriptor = true;
+        SG_LOG(SG_INPUT, SG_INFO, GetUniqueName() << " will configure using local HID descriptor");
+        
+        for (auto report : node->getChild("hid-descriptor")->getChildren("report")) {
+            defineReport(report);
+        }
+    }
+}
+
 bool FGHIDDevice::Open()
 {
     _device = hid_open_path(_hidPath.c_str());
@@ -356,39 +393,72 @@ bool FGHIDDevice::Open()
         return false;
     }
 
-    unsigned char reportDescriptor[1024];
-    int descriptorSize = hid_get_descriptor(_device, reportDescriptor, 1024);
-
-    hid_item* rootItem = nullptr;
-    hid_parse_reportdesc(reportDescriptor, descriptorSize, &rootItem);
-
-    scanCollection(rootItem);
-
-    hid_free_reportdesc(rootItem);
-
+    if (!_haveLocalDescriptor) {
+        bool ok = parseUSBHIDDescriptor();
+        if (!ok)
+            return false;
+    }
+    
     for (auto& v : handledEvents) {
         auto reportItem = itemWithName(v.first);
         if (!reportItem.second) {
-            SG_LOG(SG_INPUT, SG_WARN, "HID device has no element for event:" << v.first);
+            SG_LOG(SG_INPUT, SG_WARN, "HID device:" << GetUniqueName() << " has no element for event:" << v.first);
             continue;
         }
 
         FGInputEvent_ptr event = v.second;
-       // SG_LOG(SG_INPUT, SG_INFO, "found item for event:" << v.first);
+        if (debugEvents) {
+            SG_LOG(SG_INPUT, SG_INFO, "found item for event:" << v.first);
+        }
+        
         reportItem.second->event = event;
     }
 
     return true;
 }
+    
+bool FGHIDDevice::parseUSBHIDDescriptor()
+{
+    unsigned char reportDescriptor[1024];
+    int descriptorSize = hid_get_descriptor(_device, reportDescriptor, 1024);
+    if (descriptorSize <= 0) {
+        SG_LOG(SG_INPUT, SG_WARN, "HID: " << GetUniqueName() << " failed to read HID descriptor");
+        return false;
+    }
+    
+#if defined(HID_INPUT_DEBUG)
+    SG_LOG(SG_INPUT, SG_INFO, "\nHID: descriptor for:" << GetUniqueName());
+    {
+        std::ostringstream byteString;
+        
+        for (int i=0; i<descriptorSize; ++i) {
+            byteString << hexTable[reportDescriptor[i] >> 4];
+            byteString << hexTable[reportDescriptor[i] & 0x0f];
+            byteString << " ";
+        }
+        SG_LOG(SG_INPUT, SG_INFO, "\tbytes: " << byteString.str());
+    }
+#endif
+    
+    hid_item* rootItem = nullptr;
+    hid_parse_reportdesc(reportDescriptor, descriptorSize, &rootItem);
+#if defined(HID_INPUT_DEBUG)
+    SG_LOG(SG_INPUT, SG_INFO, "\nHID: scan for:" << GetUniqueName());
+#endif
+    parseCollection(rootItem);
+    
+    hid_free_reportdesc(rootItem);
+    return true;
+}
 
-void FGHIDDevice::scanCollection(hid_item* c)
+void FGHIDDevice::parseCollection(hid_item* c)
 {
     for (hid_item* child = c->collection; child != nullptr; child = child->next) {
         if (child->collection) {
-            scanCollection(child);
+            parseCollection(child);
         } else {
             // leaf item
-            scanItem(child);
+            parseItem(child);
         }
     }
 }
@@ -443,7 +513,7 @@ uint8_t FGHIDDevice::countWithName(const std::string& name) const
     return result;
 }
 
-void FGHIDDevice::scanItem(hid_item* item)
+void FGHIDDevice::parseItem(hid_item* item)
 {
     std::string name = HID::nameForUsage(item->usage >> 16, item->usage & 0xffff);
     if (hid_parse_is_relative(item)) {
@@ -488,12 +558,13 @@ void FGHIDDevice::scanItem(hid_item* item)
     auto report = getReport(ty, item->report_id, true /* create */);
     uint32_t bitOffset = report->currentBitSize();
 
-    SG_LOG(SG_INPUT, SG_INFO, "adding item:" << name);
+    if (debugEvents) {
+        SG_LOG(SG_INPUT, SG_INFO, GetUniqueName() << ": add:" << name << ", bits: " << bitOffset << ":" << (int) item->report_size
+            << ", report=" << (int) item->report_id);
+    }
+
     Item* itemObject = new Item{name, bitOffset, item->report_size};
     itemObject->isRelative = hid_parse_is_relative(item);
-
-    SG_LOG(SG_INPUT, SG_INFO, "\t logical min-max:" << item->logical_min << " / " << item->logical_max);
-
     itemObject->doSignExtend = (item->logical_min < 0) || (item->logical_max < 0);
     report->items.push_back(itemObject);
 }
@@ -525,7 +596,8 @@ void FGHIDDevice::update(double dt)
         const uint8_t reportNumber = _haveNumberedReports ? reportBuf[0] : 0;
         auto inputReport = getReport(HID::ReportType::In, reportNumber, false);
         if (!inputReport) {
-            SG_LOG(SG_INPUT, SG_WARN, "FGHIDDevice: Unknown input report number");
+            SG_LOG(SG_INPUT, SG_WARN, "FGHIDDevice: Unknown input report number:" << 
+                static_cast<int>(reportNumber));
         } else {
             uint8_t* reportBytes = _haveNumberedReports ? reportBuf + 1 : reportBuf;
             size_t reportSize = _haveNumberedReports ? readCount -  1 : readCount;
@@ -582,17 +654,19 @@ void FGHIDDevice::processInputReport(Report* report, unsigned char* data,
                                      size_t length,
                                      double dt, int keyModifiers)
 {
-    //SG_LOG(SG_INPUT, SG_INFO, "Report " << report->number);
-#if 0
-    {
-        std::ostringstream byteString;
-        byteString << std::hex;
-        for (int i=0; i<length; ++i) {
-            byteString << (int) data[i] << " ";
+    if (debugEvents) {
+        SG_LOG(SG_INPUT, SG_INFO, "Report:" << (int) report->number << ", len=" << length);
+        {
+            std::ostringstream byteString;
+        
+            for (int i=0; i<length; ++i) {
+                byteString << hexTable[data[i] >> 4];
+                byteString << hexTable[data[i] & 0x0f];
+                byteString << " ";
+            }
+            SG_LOG(SG_INPUT, SG_INFO, "\tbytes: " << byteString.str());
         }
-        SG_LOG(SG_INPUT, SG_INFO, "\tbytes: " << byteString.str());
     }
-#endif
 
     for (auto item : report->items) {
         int value = extractBits(data, length, item->bitOffset, item->bitSize);
@@ -616,7 +690,9 @@ void FGHIDDevice::processInputReport(Report* report, unsigned char* data,
         if (!item->event)
             continue;
 
-        SG_LOG(SG_INPUT, SG_INFO, "\titem:" << item->name << " = " << value);
+        if (debugEvents) {
+            SG_LOG(SG_INPUT, SG_INFO, "\titem:" << item->name << " = " << value);
+        }
 
         HIDEventData event{item, value, dt, keyModifiers};
         HandleEvent(event);
@@ -659,6 +735,60 @@ void FGHIDDevice::Send(const char *eventName, double value)
     item.second->lastValue = intValue;
     _dirtyReports.insert(item.first);
 }
+    
+void FGHIDDevice::defineReport(SGPropertyNode_ptr reportNode)
+{
+    const int nChildren = reportNode->nChildren();
+    uint32_t bitCount = 0;
+    const auto rty = HID::reportTypeFromString(reportNode->getStringValue("type"));
+    if (rty == HID::ReportType::Invalid) {
+        SG_LOG(SG_INPUT, SG_WARN, "FGHIDDevice: invalid report type:" <<
+               reportNode->getStringValue("type"));
+        return;
+    }
+
+    const auto id = reportNode->getIntValue("id");
+    if (id > 0) {
+        _haveNumberedReports = true;
+    }
+
+    auto report = new Report(rty, id);
+    _reports.push_back(report);
+
+    for (int c=0; c < nChildren; ++c) {
+        const auto nd = reportNode->getChild(c);
+        const int size = nd->getIntValue("size", 1); // default to a single bit
+        if (!strcmp(nd->getName(), "unused-bits")) {
+            bitCount += size;
+            continue;
+        }
+        
+        if (!strcmp(nd->getName(), "type") || !strcmp(nd->getName(), "id")) {
+            continue; // already handled above
+        }
+        
+        // allow repeating items
+        uint8_t count = nd->getIntValue("count", 1);
+        std::string name = nd->getNameString();
+        const auto lastHypen = name.rfind("-");
+        std::string baseName = name.substr(0, lastHypen + 1);
+        int baseIndex = std::stoi(name.substr(lastHypen + 1));
+        
+        const bool isRelative = (name.find("rel-") == 0);
+        const bool isSigned = nd->getBoolValue("is-signed", false);
+        
+        for (uint8_t i=0; i < count; ++i) {
+            std::ostringstream oss;
+            oss << baseName << (baseIndex + i);
+            Item* itemObject = new Item{oss.str(), bitCount, static_cast<uint8_t>(size)};
+            itemObject->isRelative = isRelative;
+            itemObject->doSignExtend = isSigned;
+            report->items.push_back(itemObject);
+            bitCount += size;
+        }
+    }
+}
+
 
 } // of anonymous namespace
 
@@ -767,8 +897,9 @@ void FGHIDEventInput::update(double dt)
 
 void FGHIDEventInput::FGHIDEventInputPrivate::evaluateDevice(hid_device_info* deviceInfo)
 {
-    SG_LOG(SG_INPUT, SG_DEBUG, "HID device:" << deviceInfo->product_string << " from " << deviceInfo->manufacturer_string);
-
+#if defined(HID_INPUT_DEBUG)
+    SG_LOG(SG_INPUT, SG_INFO, "HID device:" << deviceInfo->product_string << " from " << deviceInfo->manufacturer_string);
+#endif
     // allocate an input device, and add to the base class to see if we have
     // a config
     p->AddDevice(new FGHIDDevice(deviceInfo, p));
