@@ -22,7 +22,6 @@
 
 #include <config.h>
 
-#include <boost/foreach.hpp>
 #include <algorithm>
 
 #include <osgViewer/Viewer>
@@ -145,7 +144,7 @@ FGGlobals *globals = NULL;
 // Constructor
 FGGlobals::FGGlobals() :
     renderer( new FGRenderer ),
-    subsystem_mgr( new SGSubsystemMgr ),
+    subsystem_mgr( new SGSubsystemMgr("subsystem_mgr") ),
     event_mgr( new SGEventMgr ),
     sim_time_sec( 0.0 ),
     fg_root( "" ),
@@ -279,6 +278,12 @@ void FGGlobals::set_fg_home (const SGPath &home)
     fg_home = home.realpath();
 }
 
+void FGGlobals::set_texture_cache_dir(const SGPath &textureCache)
+{
+    texture_cache_dir = textureCache.realpath();
+}
+
+
 PathList FGGlobals::get_data_paths() const
 {
     PathList r(additional_data_paths);
@@ -289,7 +294,7 @@ PathList FGGlobals::get_data_paths() const
 PathList FGGlobals::get_data_paths(const std::string& suffix) const
 {
     PathList r;
-    BOOST_FOREACH(SGPath p, get_data_paths()) {
+    for (SGPath p : get_data_paths()) {
         p.append(suffix);
         if (p.exists()) {
             r.push_back(p);
@@ -310,7 +315,7 @@ void FGGlobals::append_data_path(const SGPath& path)
 
 SGPath FGGlobals::find_data_dir(const std::string& pathSuffix) const
 {
-    BOOST_FOREACH(SGPath p, additional_data_paths) {
+    for (SGPath p : additional_data_paths) {
         p.append(pathSuffix);
         if (p.exists()) {
             return p;
