@@ -21,6 +21,7 @@
 
 #include "airways.hxx"
 
+#include <tuple>
 #include <algorithm>
 #include <set>
 
@@ -29,9 +30,6 @@
 #include <simgear/io/iostreams/sgstream.hxx>
 #include <simgear/misc/sg_path.hxx>
 
-#include <boost/foreach.hpp>
-#include <boost/tuple/tuple.hpp>
-
 #include <Main/globals.hxx>
 #include <Navaids/positioned.hxx>
 #include <Navaids/waypoint.hxx>
@@ -181,8 +179,18 @@ void Airway::loadAWYDat(const SGPath& path)
 WayptVec::const_iterator Airway::find(WayptRef wpt) const
 {
     assert(!_elements.empty());
+    if (wpt->type() == "via") {
+      // map vias to their end navaid / fix, so chaining them
+      // together works. (Temporary waypoint is discarded after search)
+      wpt = new NavaidWaypoint(wpt->source(), wpt->owner());
+    }
+
     return std::find_if(_elements.begin(), _elements.end(),
-                     [wpt] (const WayptRef& w) { return w->matches(wpt); });
+                        [wpt] (const WayptRef& w)
+                        {
+                            if (!w) return false;
+                            return w->matches(wpt);
+                        });
 }
 
 bool Airway::canVia(const WayptRef& from, const WayptRef& to) const
@@ -286,7 +294,10 @@ AirwayRef Airway::findByIdent(const std::string& aIdent, Level level)
 {
     auto it = std::find_if(static_airwaysCache.begin(), static_airwaysCache.end(),
                            [aIdent, level](const AirwayRef& awy)
-    { return (awy->_level == level) && (awy->ident() == aIdent); });
+    { 
+      if ((level != Both) && (awy->_level != level)) return false;
+      return (awy->ident() == aIdent); 
+    });
     if (it != static_airwaysCache.end()) {
         return *it;
     }
@@ -294,7 +305,6 @@ AirwayRef Airway::findByIdent(const std::string& aIdent, Level level)
     NavDataCache* ndc = NavDataCache::instance();
     int airwayId = ndc->findAirway(level, aIdent, false);
     if (airwayId == 0) {
-        SG_LOG(SG_GENERAL, SG_INFO, "fooooo");
         return {};
     }
 
@@ -369,6 +379,7 @@ AirwayRef Airway::findByIdentAndNavaid(const std::string& aIdent, const FGPositi
 
 WayptRef Airway::findEnroute(const std::string &aIdent) const
 {
+    loadWaypoints();
     auto it = std::find_if(_elements.begin(), _elements.end(),
                            [&aIdent](WayptRef w)
     {
@@ -435,8 +446,8 @@ bool Airway::Network::route(WayptRef aFrom, WayptRef aTo,
 
   FGPositionedRef from, to;
   bool exactTo, exactFrom;
-  boost::tie(from, exactFrom) = findClosestNode(aFrom);
-  boost::tie(to, exactTo) = findClosestNode(aTo);
+  std::tie(from, exactFrom) = findClosestNode(aFrom);
+  std::tie(to, exactTo) = findClosestNode(aTo);
   
 #ifdef DEBUG_AWY_SEARCH
   SG_LOG(SG_NAVAID, SG_INFO, "from:" << from->ident() << "/" << from->name());
@@ -507,7 +518,7 @@ Airway::Network::findClosestNode(WayptRef aRef)
 class InAirwayFilter : public FGPositioned::Filter
 {
 public:
-  InAirwayFilter(Airway::Network* aNet) :
+  InAirwayFilter(const Airway::Network* aNet) :
     _net(aNet)
   { ; }
   
@@ -523,7 +534,7 @@ public:
   { return FGPositioned::VOR; }
   
 private:
-  Airway::Network* _net;
+  const Airway::Network* _net;
 };
 
 std::pair<FGPositionedRef, bool> 
@@ -540,6 +551,13 @@ Airway::Network::findClosestNode(const SGGeod& aGeod)
   return make_pair(r, exact);
 }
 
+FGPositionedRef
+Airway::Network::findNodeByIdent(const std::string& ident, const SGGeod& near) const
+{
+    InAirwayFilter f(this);
+    return FGPositioned::findClosestWithIdent(ident, near, &f);
+}
+
 /////////////////////////////////////////////////////////////////////////////
 
 typedef vector<AStarOpenNodeRef> OpenNodeHeap;
@@ -556,9 +574,10 @@ static void buildWaypoints(AStarOpenNodeRef aNode, WayptVec& aRoute)
   for (n = aNode; n; n=n->previous) {
       // get / create airway to be the owner for this waypoint
       AirwayRef awy = Airway::loadByCacheId(n->airway);
-   //   assert(awy);
       auto wp = new NavaidWaypoint(n->node, awy);
-      wp->setFlag(WPT_VIA);
+      if (awy) {
+          wp->setFlag(WPT_VIA);
+      }
       wp->setFlag(WPT_GENERATED);
       aRoute[--count] = wp;
   }
