@@ -81,7 +81,11 @@ SplashScreen::~SplashScreen()
 
 void SplashScreen::createNodes()
 {
+#if OSG_VERSION_LESS_THAN(3,4,0)
+    _splashImage = osgDB::readImageFile(selectSplashImage());
+#else
     _splashImage = osgDB::readRefImageFile(selectSplashImage());
+#endif
 
     int width = _splashImage->s();
     int height = _splashImage->t();
@@ -220,7 +224,7 @@ void SplashScreen::createNodes()
     _splashQuadCamera->setClearMask( 0 );
     _splashQuadCamera->setAllowEventFocus(false);
     _splashQuadCamera->setCullingActive(false);
-    _splashQuadCamera->setRenderOrder(osg::Camera::POST_RENDER, 20000);
+    _splashQuadCamera->setRenderOrder(osg::Camera::NESTED_RENDER, 20000);
     
     stateSet = _splashQuadCamera->getOrCreateStateSet();
     stateSet->setMode(GL_BLEND, osg::StateAttribute::ON);
@@ -277,11 +281,15 @@ void SplashScreen::setupLogoImage()
 {
     // check for a logo image, add underneath other text
     SGPath logoPath = globals->resolve_maybe_aircraft_path(fgGetString("/sim/startup/splash-logo-image"));
-    if (!logoPath.exists()) {
+    if (!logoPath.exists() || !logoPath.isFile()) {
         return;
     }
 
+#if OSG_VERSION_LESS_THAN(3,4,0)
+    _logoImage = osgDB::readImageFile(logoPath.utf8Str());
+#else
     _logoImage = osgDB::readRefImageFile(logoPath.utf8Str());
+#endif
     if (!_logoImage) {
         return;
     }
